@@ -10,7 +10,7 @@ es <- function(data, model="ZZZ", persistence=NULL, phi=NULL,
                cfType=c("MSE","MAE","HAM","MLSTFE","MSTFE","MSEh"),
                h=10, holdout=FALSE,
                intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
-               intermittent=c("none","auto","fixed","croston","tsb"),
+               intermittent=c("none","auto","fixed","croston","tsb","sba"),
                bounds=c("usual","admissible","none"),
                silent=c("none","all","graph","legend","output"),
                xreg=NULL, initialX=NULL, updateX=FALSE, persistenceX=NULL, transitionX=NULL, ...){
@@ -525,10 +525,11 @@ EstimatorES <- function(...){
 
     ICValues <- ICFunction(n.param=n.param+n.param.intermittent,C=res$solution,Etype=Etype);
     ICs <- ICValues$ICs;
+    logLik <- ICValues$llikelihood;
 
     # Change back
     cfType <- cfTypeOriginal;
-    return(list(ICs=ICs,objective=res$objective,C=C,n.param=n.param,FI=FI));
+    return(list(ICs=ICs,objective=res$objective,C=C,n.param=n.param,FI=FI,logLik=logLik));
 }
 
 ##### This function prepares pool of models to use #####
@@ -648,7 +649,7 @@ PoolPreparerES <- function(...){
 
                 res <- EstimatorES(ParentEnvironment=environment());
 
-                results[[i]] <- c(res$ICs,Etype,Ttype,Stype,damped,res$objective,res$C,res$n.param);
+                results[[i]] <- c(res$ICs,Etype,Ttype,Stype,damped,res$objective,res$C,res$n.param,res$logLik);
 
                 tested.model <- c(tested.model,current.model);
 
@@ -781,16 +782,14 @@ PoolEstimatorES <- function(silent=FALSE,...){
         }
 
         res <- EstimatorES(ParentEnvironment=environment());
-        results[[j]] <- c(res$ICs,Etype,Ttype,Stype,damped,res$objective,res$C,res$n.param);
+        results[[j]] <- c(res$ICs,Etype,Ttype,Stype,damped,res$objective,res$C,res$n.param,res$logLik);
     }
 
     if(!silent){
         cat("... Done! \n");
     }
     icSelection <- matrix(NA,models.number,3);
-#    icSelection <- rep(NA,models.number);
     for(i in 1:models.number){
-#        icSelection[i,] <- as.numeric(eval(parse(text=paste0("results[[",i,"]]['",ic,"']"))));
         icSelection[i,] <- as.numeric(results[[i]][1:3]);
     }
     colnames(icSelection) <- names(results[[1]])[1:3]
@@ -824,10 +823,11 @@ CreatorES <- function(silent=FALSE,...){
             phi <- NULL;
         }
         cfObjective <- as.numeric(results[8]);
-        C <- as.numeric(results[-c(1:8)]);
+        C <- as.numeric(results[-c(1:8,length(results)-1,length(results))]);
+        logLik <- as.numeric(results[length(results)]);
 
         return(list(Etype=Etype,Ttype=Ttype,Stype=Stype,damped=damped,phi=phi,
-                    cfObjective=cfObjective,C=C,ICs=ICs,icBest=icBest,n.param=as.numeric(results[length(results)]),FI=FI));
+                    cfObjective=cfObjective,C=C,ICs=ICs,icBest=icBest,n.param=as.numeric(results[length(results)-1]),FI=FI,logLik=logLik));
     }
     else if(modelDo=="combine"){
         if(cfType!="MSE"){
@@ -842,15 +842,16 @@ CreatorES <- function(silent=FALSE,...){
         icSelection <- icSelection/(h^multisteps);
         icWeights <- exp(-0.5*(icSelection-icBest))/sum(exp(-0.5*(icSelection-icBest)));
         ICs <- sum(icSelection * icWeights);
-        return(list(icWeights=icWeights,ICs=ICs,icBest=icBest,results=results));
+        return(list(icWeights=icWeights,ICs=ICs,icBest=icBest,results=results,logLik=NA));
     }
     else if(modelDo=="estimate"){
         environment(EstimatorES) <- environment();
         res <- EstimatorES(ParentEnvironment=environment());
         icBest <- res$ICs[ic];
+        logLik <- res$logLik;
 
         return(list(Etype=Etype,Ttype=Ttype,Stype=Stype,damped=damped,phi=phi,
-                    cfObjective=res$objective,C=res$C,ICs=res$ICs,icBest=icBest,n.param=res$n.param,FI=FI));
+                    cfObjective=res$objective,C=res$C,ICs=res$ICs,icBest=icBest,n.param=res$n.param,FI=FI,logLik=logLik));
     }
     else{
         environment(CF) <- environment();
@@ -878,25 +879,21 @@ CreatorES <- function(silent=FALSE,...){
 
 # Change cfType for model selection
         if(multisteps){
-            #     if(substring(cfType,1,1)=="a"){
             cfType <- "aTFL";
-            #     }
-            #     else{
-            #         cfType <- "TFL";
-            #     }
         }
         else{
             cfType <- "MSE";
         }
 
         ICValues <- ICFunction(n.param=n.param+n.param.intermittent,C=C,Etype=Etype);
+        logLik <- ICValues$llikelihood;
         ICs <- ICValues$ICs;
         icBest <- ICs[ic];
         # Change back
         cfType <- cfTypeOriginal;
 
         return(list(Etype=Etype,Ttype=Ttype,Stype=Stype,damped=damped,phi=phi,
-                    cfObjective=cfObjective,C=C,ICs=ICs,icBest=icBest,n.param=n.param,FI=FI));
+                    cfObjective=cfObjective,C=C,ICs=ICs,icBest=icBest,n.param=n.param,FI=FI,logLik=logLik));
     }
 }
 
@@ -907,9 +904,23 @@ CreatorES <- function(silent=FALSE,...){
     environment(ssFitter) <- environment();
     environment(ssForecaster) <- environment();
 
+    EtypeOriginal <- Etype;
+    TtypeOriginal <- Ttype;
+    StypeOriginal <- Stype;
 # If auto intermittent, then estimate model with intermittent="n" first.
     if(any(intermittent==c("a","n"))){
         intermittentParametersSetter(intermittent="n",ParentEnvironment=environment());
+        if(intermittent=="a"){
+            if(Etype=="M"){
+                Etype <- "A";
+            }
+            if(Ttype=="M"){
+                Ttype <- "A";
+            }
+            if(Stype=="M"){
+                Stype <- "A";
+            }
+        }
     }
     else{
         intermittentParametersSetter(intermittent=intermittent,ParentEnvironment=environment());
@@ -919,6 +930,9 @@ CreatorES <- function(silent=FALSE,...){
 
 ##### If intermittent=="a", run a loop and select the best one #####
     if(intermittent=="a"){
+        Etype <- EtypeOriginal;
+        Ttype <- TtypeOriginal;
+        Stype <- StypeOriginal;
         if(cfType!="MSE"){
             warning(paste0("'",cfType,"' is used as cost function instead of 'MSE'. A wrong intermittent model may be selected"),call.=FALSE);
         }
@@ -926,7 +940,7 @@ CreatorES <- function(silent=FALSE,...){
             cat("Selecting appropriate type of intermittency... ");
         }
 # Prepare stuff for intermittency selection
-        intermittentModelsPool <- c("n","f","c","t");
+        intermittentModelsPool <- c("n","f","c","t","s");
         intermittentICs <- rep(NA,length(intermittentModelsPool));
         intermittentModelsList <- list(NA);
         intermittentICs <- esValues$icBest;
@@ -1152,7 +1166,7 @@ CreatorES <- function(silent=FALSE,...){
                       errors=errors.mat,s2=s2,intervals=intervalsType,level=level,
                       actuals=data,holdout=y.holdout,iprob=pt,intermittent=intermittent,
                       xreg=xreg,updateX=updateX,initialX=initialX,persistenceX=vecgX,transitionX=matFX,
-                      ICs=ICs,cf=cfObjective,cfType=cfType,FI=FI,accuracy=errormeasures);
+                      ICs=ICs,logLik=logLik,cf=cfObjective,cfType=cfType,FI=FI,accuracy=errormeasures);
         return(structure(model,class="smooth"));
     }
     else{
