@@ -8,7 +8,7 @@ ges <- function(data, orders=c(1,1), lags=c(1,frequency(data)),
                 cfType=c("MSE","MAE","HAM","MLSTFE","MSTFE","MSEh"),
                 h=10, holdout=FALSE,
                 intervals=c("none","parametric","semiparametric","nonparametric"), level=0.95,
-                intermittent=c("none","auto","fixed","croston","tsb"),
+                intermittent=c("none","auto","fixed","croston","tsb","sba"),
                 bounds=c("admissible","none"),
                 silent=c("none","all","graph","legend","output"),
                 xreg=NULL, initialX=NULL, updateX=FALSE, persistenceX=NULL, transitionX=NULL, ...){
@@ -291,25 +291,22 @@ CreatorGES <- function(silentText=FALSE,...){
 
 # Change cfType for model selection
     if(multisteps){
-        #     if(substring(cfType,1,1)=="a"){
         cfType <- "aTFL";
-        #     }
-        #     else{
-        #         cfType <- "TFL";
-        #     }
     }
     else{
         cfType <- "MSE";
     }
 
-    IC.values <- ICFunction(n.param=n.param+n.param.intermittent,C=C,Etype=Etype);
-    ICs <- IC.values$ICs;
+    ICValues <- ICFunction(n.param=n.param+n.param.intermittent,C=C,Etype=Etype);
+    ICs <- ICValues$ICs;
+    logLik <- ICValues$llikelihood;
+
     icBest <- ICs["AICc"];
 
 # Revert to the provided cost function
     cfType <- cfTypeOriginal
 
-    return(list(cfObjective=cfObjective,C=C,ICs=ICs,icBest=icBest,n.param=n.param));
+    return(list(cfObjective=cfObjective,C=C,ICs=ICs,icBest=icBest,n.param=n.param,logLik=logLik));
 }
 
 ##### Start the calculations #####
@@ -338,7 +335,7 @@ CreatorGES <- function(silentText=FALSE,...){
             cat("Selecting appropriate type of intermittency... ");
         }
 # Prepare stuff for intermittency selection
-        intermittentModelsPool <- c("n","f","c","t");
+        intermittentModelsPool <- c("n","f","c","t","s");
         intermittentICs <- rep(1e+10,length(intermittentModelsPool));
         intermittentModelsList <- list(NA);
         intermittentICs <- gesValues$icBest;
@@ -484,6 +481,6 @@ CreatorGES <- function(silentText=FALSE,...){
                   errors=errors.mat,s2=s2,intervals=intervalsType,level=level,
                   actuals=data,holdout=y.holdout,iprob=pt,intermittent=intermittent,
                   xreg=xreg,updateX=updateX,initialX=initialX,persistenceX=vecgX,transitionX=matFX,
-                  ICs=ICs,cf=cfObjective,cfType=cfType,FI=FI,accuracy=errormeasures);
+                  ICs=ICs,logLik=logLik,cf=cfObjective,cfType=cfType,FI=FI,accuracy=errormeasures);
     return(structure(model,class="smooth"));
 }
