@@ -12,9 +12,9 @@ test_that("Test on N1234$x, predefined CES", {
 })
 
 # Test trace cost function for CES
-testModel <- ces(Mcomp::M3$N2568$x, seasonality="f", h=18, holdout=TRUE, cfType="MSTFE", silent=TRUE, intervals=TRUE)
+testModel <- ces(Mcomp::M3$N2568$x, seasonality="f", h=18, holdout=TRUE, silent=TRUE, intervals=TRUE)
 test_that("Test AICc of CES based on MSTFE on N2568$x", {
-    expect_equal(AICc(testModel), testModel$ICs["AICc"]);
+    expect_equal(round(AICc(testModel),2), as.numeric(round(testModel$ICs["AICc"],2)));
 })
 
 # Test how different passed values are accepted by CES
